@@ -52,12 +52,13 @@ PrefInterface::PrefInterface(QWidget * parent, Qt::WindowFlags f)
 	style_label->hide();
 	style_combo->hide();
 #else
-	style_combo->addItem( "<default>" );
+	style_combo->addItem( "Default" );
 	style_combo->addItems( QStyleFactory::keys() );
 #endif
 
 	// Icon set combo
-	iconset_combo->addItem( "Default" );
+	iconset_combo->addItem( "H2O", "H2O" );
+	iconset_combo->addItem( "Default", "" );
 
 #ifdef SKINS
 	n_skins = 0;
@@ -73,12 +74,12 @@ PrefInterface::PrefInterface(QWidget * parent, Qt::WindowFlags f)
 		bool is_skin = QFile::exists(css_file);
 		//qDebug("***** %s %d", css_file.toUtf8().constData(), is_skin);
 		if (is_skin) {
-			skin_combo->addItem( iconsets[n] );
+			skin_combo->addItem( iconsets[n], iconsets[n] );
 			n_skins++;
 		}
 		else
 		#endif
-		iconset_combo->addItem( iconsets[n] );
+		iconset_combo->addItem( iconsets[n], iconsets[n] );
 	}
 	// Global
 	icon_dir = Paths::themesPath();
@@ -89,20 +90,20 @@ PrefInterface::PrefInterface(QWidget * parent, Qt::WindowFlags f)
 		QString css_file = Paths::themesPath() + "/" + iconsets[n] + "/main.css";
 		bool is_skin = QFile::exists(css_file);
 		//qDebug("***** %s %d", css_file.toUtf8().constData(), is_skin);
-		if ((is_skin) && (skin_combo->findText( iconsets[n] ) == -1)) {
-			skin_combo->addItem( iconsets[n] );
+		if ((is_skin) && (skin_combo->findData( iconsets[n] ) == -1)) {
+			skin_combo->addItem( iconsets[n], iconsets[n] );
 			n_skins++;
 		}
 		else
 		#endif
-		if (iconset_combo->findText( iconsets[n] ) == -1) {
-			iconset_combo->addItem( iconsets[n] );
+		if (iconset_combo->findData( iconsets[n] ) == -1) {
+			iconset_combo->addItem( iconsets[n], iconsets[n] );
 		}
 	}
 	#ifdef SKINS
 	if (skin_combo->itemText(0) == "Black") {
 		skin_combo->removeItem(0);
-		skin_combo->addItem("Black");
+		skin_combo->addItem("Black", "Black");
 	}
 	#endif
 
@@ -215,7 +216,12 @@ void PrefInterface::retranslateStrings() {
 	language_combo->setCurrentIndex( language_item );
 
 	// Iconset combo
-	iconset_combo->setItemText( 0, tr("Default") );
+	{
+		int pos = iconset_combo->findData("");
+		if (pos != -1) iconset_combo->setItemText(pos, tr("Classic"));
+		pos = iconset_combo->findData("H2O");
+		if (pos != -1) iconset_combo->setItemText(pos, tr("Default"));
+	}
 
 #if STYLE_SWITCHING
 	style_combo->setItemText( 0, tr("Default") );
@@ -416,27 +422,14 @@ QString PrefInterface::language() {
 }
 
 void PrefInterface::setIconSet(QString set) {
-	/*
-	if (set.isEmpty())
-		iconset_combo->setCurrentIndex(0);
-	else
-		iconset_combo->setCurrentText(set);
-	*/
 	iconset_combo->setCurrentIndex(0);
-	for (int n=0; n < iconset_combo->count(); n++) {
-		if (iconset_combo->itemText(n) == set) {
-			iconset_combo->setCurrentIndex(n);
-			break;
-		}
-	}
+	int pos = iconset_combo->findData(set);
+	if (pos != -1) iconset_combo->setCurrentIndex(pos);
+
 #ifdef SKINS
 	skin_combo->setCurrentIndex(0);
-	for (int n=0; n < skin_combo->count(); n++) {
-		if (skin_combo->itemText(n) == set) {
-			skin_combo->setCurrentIndex(n);
-			break;
-		}
-	}
+	pos = skin_combo->findData(set);
+	if (pos != -1) skin_combo->setCurrentIndex(pos);
 #endif
 }
 
@@ -444,14 +437,11 @@ QString PrefInterface::iconSet() {
 #ifdef SKINS
 	QString GUI = gui_combo->itemData(gui_combo->currentIndex()).toString();
 	if (GUI == "SkinGUI") {
-		return skin_combo->currentText();
+		return skin_combo->itemData(skin_combo->currentIndex()).toString();
 	}
 	else
 #endif
-	if (iconset_combo->currentIndex()==0) 
-		return "";
-	else
-		return iconset_combo->currentText();
+	return iconset_combo->itemData(iconset_combo->currentIndex()).toString();
 }
 
 void PrefInterface::setResizeMethod(int v) {
