@@ -60,6 +60,10 @@ PrefNetwork::PrefNetwork(QWidget * parent, Qt::WindowFlags f)
 	youtube_box->hide();
 #endif
 
+#ifndef CONVERT_TO_VTT
+	subs_box->hide();
+#endif
+
 	retranslateStrings();
 }
 
@@ -115,6 +119,13 @@ void PrefNetwork::setData(Preferences * pref) {
 	setLocalIP(cc->localAddress(), cc->localAddresses());
 	port_spin->setValue(cc->serverPort());
 	directory_listing_check->setChecked(cc->directoryListing());
+
+	#ifdef CONVERT_TO_VTT
+	convert_subs_check->setChecked(cc->autoConvertToVTT());
+	subs_position_spin->setValue(cc->subtitlePosition());
+	overwrite_subs_check->setChecked(cc->overwriteVTT());
+	subs_filter_check->setChecked(cc->isSubtitleFilterEnabled());
+	#endif
 #endif
 }
 
@@ -140,6 +151,13 @@ void PrefNetwork::getData(Preferences * pref) {
 	cc->setLocalAddress(localIP());
 	cc->setServerPort(port_spin->value());
 	cc->setDirectoryListing(directory_listing_check->isChecked());
+
+	#ifdef CONVERT_TO_VTT
+	cc->setAutoConvertToVTT(convert_subs_check->isChecked());
+	cc->setSubtitlePosition(subs_position_spin->value());
+	cc->setOverwriteVTT(overwrite_subs_check->isChecked());
+	cc->enableSubtitleFilter(subs_filter_check->isChecked());
+	#endif
 #endif
 }
 
@@ -263,6 +281,24 @@ void PrefNetwork::createHelp() {
            "files from this computer. If this option is on, any device can get a listing "
            "of the files in this computer. "
            "If this option is off, the list won't be available.") );
+
+	#ifdef CONVERT_TO_VTT
+	setWhatsThis(convert_subs_check, tr("Convert SRT subtitles to VTT"),
+		tr("When this option is enabled SMPlayer will convert automatically subtitle files "
+           "in SRT format to VTT format. The VTT subtitle will have the same filename but extension .vtt"));
+
+	setWhatsThis(overwrite_subs_check, tr("Overwrite existing VTT files"),
+		tr("If this option is enabled SMPlayer will overwrite existing VTT files."));
+
+	setWhatsThis(subs_filter_check, tr("Try to remove advertisements"),
+		tr("If this option is enabled SMPlayer will try to find advertisements "
+           "in the subtitles and remove them."));
+
+	setWhatsThis(subs_position_spin, tr("Position of subtitles on screen"),
+		tr("This option sets the position on the screen where the subtitles are displayed.") +"<br>"+
+		tr("0 is the top of the screen, 100 is the bottom of the screen.") +" "+
+		tr("The special value -1 means the default position."));
+	#endif
 #endif
 
 	addSectionTitle(tr("Proxy"));
